/*

  Temperature Humidity Pressure Sensor BME280

  Parts required:
  - Arduino Board
  - Temperature Humidity Pressure Sensor BME280

  Libraries:
  - Adafruit_Sensor
  - Adafruit_BME280

  Programming by : René Rasmussen
  Website : www.it-teknolog.dk
  Contact : renerasmussen@it-teknolog.dk
  Date : 28 Mar 2020
  Version : v1.0

  Modulet kan købes på www.arduinotech.dk

*/

#include <Wire.h>                                           // includes library Wire.h
#include <SPI.h>                                            // includes library SPI.h
#include <Adafruit_Sensor.h>                                // includes library Adafruit_Sensor.h
#include <Adafruit_BME280.h>                                // includes library Adafruit_BME280.h

#define seaLevelPressure_hPA (1013.25)                      // create variable and store value 

int status;                                                 // create variable

Adafruit_BME280 bme;                                        // create object bme from Adafruit_BME280

void setup() {
    Serial.begin(9600);                                     // start serial monitor
    while(!Serial);                                         // wait for serial monitor is ready
    Serial.println(F("--- BME280 Started ---"));            // print text to serial monitor
   
    status = bme.begin(0x76);                               // set variable to bme object and add I2C adress
}

void loop() { 
    Serial.print("Temperature = ");                         // print text to serial monitor
    Serial.print(bme.readTemperature());                    // print bme.readTemperature to serial monitor
    Serial.println(" C");                                   // print text to serial monitor

    Serial.print("Pressure = ");                            // print text to serial monitor

    Serial.print(bme.readPressure() / 100.0F);              // print bme.readPressure to serial monitor
    Serial.println(" hPa");                                 // print text to serial monitor

    Serial.print("Approx Altitude = ");                     // print text to serial monitor
    Serial.print(bme.readAltitude(seaLevelPressure_hPA));   // print bme.readAltitude(seaLevelPressure_hPA to serial monitor
    Serial.println(" m");                                   // print text to serial monitor

    Serial.print("Humidity = ");                            // print text to serial monitor
    Serial.print(bme.readHumidity());                       // print bme.readHumidity to serial monitor
    Serial.println(" %");                                   // print text to serial monitor

    Serial.println();                                       // print empty line to serial monitor
    delay(1000);                                            // wait 1000ms
}
